@@ -145,7 +145,6 @@ def run_command(command):
     check_test()
 
     # Execute without surpressing output
-    print(command)
     command_popen = subprocess.Popen(command, shell=True)
     command_popen.communicate()
 
@@ -172,11 +171,12 @@ def run_command_noerror(command):
 
     if command_popen.returncode:
         print("FAILED")
-        for file in os.listdir("evaluationLogs"):
-            with open(file, "r") as infile:
-                file_lines = infile.readlines()
-            # Print entire file
-            print("\n".join(file_lines))
+        if os.path.exists("evaluationLogs"):
+            for file in os.listdir("evaluationLogs"):
+                with open(file, "r") as infile:
+                    file_lines = infile.readlines()
+                # Print entire file
+                print("\n".join(file_lines))
 
         # Exit entire program with error
         sys.exit(1)
@@ -210,8 +210,8 @@ def test_case(test_case_command):
     check_test()
 
     # Clear hint
-    global hint
-    hint = ""
+    global test_case_hint
+    test_case_hint= ""
 
     # Set new test case command
     global test_args
@@ -238,8 +238,8 @@ def test_case_hidden(test_case_command):
     check_test()
 
     # Clear hint
-    global hint
-    hint = ""
+    global test_case_hint
+    test_case_hint = ""
 
     # Set new test case command
     global test_args
@@ -323,7 +323,7 @@ def check_error(error_output):
         None
     """
     with open("expectederror", "a") as outfile:
-        outfile.write(error_output)
+        outfile.write(error_output + "\n")
 
 
 def hint(hints):
@@ -362,7 +362,7 @@ def exit_code(test_case_exit_code):
         None
     """
     global expected_exit_code
-    expected_exit_code = float(test_case_exit_code)
+    expected_exit_code = int(test_case_exit_code)
 
 
 def start_server(timeout_sec, kill_timeout_sec, *server_cmd):
@@ -581,8 +581,6 @@ def check_test():
             passed = False
             break
 
-    test_args = ""
-
     # Pass fail handling
     if passed:
         global num_passed
@@ -596,20 +594,21 @@ def check_test():
         # Hidden test case handling
         if test_case_hidden:
             print("    Test Case is Hidden")
-            if hint:
-                print(f"HINT: {hint}")
+            if test_case_hint:
+                print(f"HINT: {test_case_hint}")
         else:
-            if hint:
-                print(f"HINT: {hint}")
+            if test_case_hint:
+                print(f"HINT: {test_case_hint}")
 
             # Cleanup
             print(f"    Command ran: {test_args}")
-            for file in os.listdir("evaluationLogs"):
-                with open("evaluationLogs/" + file, "r") as infile:
-                    file_lines = infile.readlines()
+            if os.path.exists("evaluationLogs"):
+                for file in os.listdir("evaluationLogs"):
+                    with open("evaluationLogs/" + file, "r") as infile:
+                        file_lines = infile.readlines()
 
-                # Print entire file
-                print("".join(file_lines))
+                    # Print entire file
+                    print("".join(file_lines))
 
         cleanup()
 
@@ -621,6 +620,8 @@ def check_test():
 
 
 def cleanup():
+    global test_args
+    test_args = ""
     files = [
         "compilelog",
         "difflog",
@@ -644,6 +645,9 @@ def cleanup():
 @click.command()
 @click.argument("codeval_file", type=click.Path(exists=True))
 def run_evaluation(codeval_file):
+    """
+    This command should be run in the docker container, so it is not usually run directly.
+    """
     start_time_seconds = time.time()
 
     setup()
@@ -655,12 +659,8 @@ def run_evaluation(codeval_file):
         for testcase in testcases:
             parts = testcase.split(" ", 1)
             tag = parts[0]
-            if tag == "T" or tag == "HT":
+            if tag == "T" or tag == "HT" or tag == "TCMD":
                 test_case_total += 1
-            elif tag == "Z":
-                filename=parts[1].strip()
-                file = os.path.join(os.path.dirname(codeval_file), filename) if filename.startswith("/") else filename
-                unzip(file, ".")
 
     # Read testcases
     with open(codeval_file, "r") as infile:
